#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of twittergeo.
# https://github.com/fitnr/twittergeo

# Licensed under the GNU General Public License v3 (GPLv3) license:
# http://opensource.org/licenses/GPL-3.0
# Copyright (c) 2015, Neil Freeman <contact@fakeisthenewreal.org>

from tweepy import Cursor

def twittergeo(method, count=None, lite=None, **kwargs):
    count = count or 100
    geojson = collection()

    for tweet in Cursor(method, **kwargs).items(count):
        feat = feature(tweet, lite=lite)

        if feat:
            geojson['features'].append(feat)

    return geojson


def collection():
    return {
        "type": "FeatureCollection",
        "features": []
    }


def feature(tweet, lite=None):
    '''
    Converts a tweepy Status object into a GeoJSON point TeatureClass

    tweet : a tweepy Status object
    lite (boolean) : If true, include only a small part of the tweet metadata
    '''
    feat = {}

    if tweet.geo:

        feat = {
            "type": "Feature",
            "geometry": {
                "type": "Point",
                "coordinates": [tweet.geo['coordinates'][1], tweet.geo['coordinates'][0]]
            }
        }

        if lite:
            feat['properties'] = {
                "screen_name": tweet.user.screen_name,
                "userid": tweet.user.id,
                "text": tweet.text,
                "id": tweet.id,
                "source": tweet.source
            }

        else:
            feat['properties'] = tweet._json

    return feat



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of twittergeo.
# https://github.com/fitnr/twittergeo

# Licensed under the GNU General Public License v3 (GPLv3) license:
# http://opensource.org/licenses/GPL-3.0
# Copyright (c) 2015, Neil Freeman <contact@fakeisthenewreal.org>

import unittest
import json
import tweepy
import twittergeo
import requests

validate_endpoint = 'http://geojsonlint.com/validate'

TWEET = {
    'follow_request_sent': None, 'has_extended_profile': False, 'profile_use_background_image': True, 'default_profile_image': True,
    'id': 61043461, 'profile_background_image_url_https': 'https://abs.twimg.com/images/themes/theme1/bg.png', 'verified': False, 'profile_text_color': '333333',
    'profile_image_url_https': 'https://abs.twimg.com/sticky/default_profile_images/default_profile_3_normal.png', 'profile_sidebar_fill_color': 'DDEEF6',
    'entities': {
        'description': {'urls': []}}, 'followers_count': 114, 'profile_sidebar_border_color': 'C0DEED',
    'id_str': '61043461', 'profile_background_color': 'C0DEED', 'listed_count': 22, 'is_translation_enabled': False, 'utc_offset': -14400,
    'statuses_count': 654785, 'description': '', 'friends_count': 0, 'location': '',
    'profile_link_color': '0084B4', 'profile_image_url': 'http://abs.twimg.com/sticky/default_profile_images/default_profile_3_normal.png', 'following': None, 'geo_enabled': True,
    'profile_background_image_url': 'http://abs.twimg.com/images/themes/theme1/bg.png', 'screen_name': 'googuns_prod', 'lang': 'en', 'profile_background_tile': False,
    'favourites_count': 0, 'name': 'GooGuns', 'notifications': None, 'url': None, 'created_at': 'Tue Jul 28 22:49:22 +0000 2009', 'contributors_enabled': False,
    'time_zone': 'Eastern Time (US & Canada)', 'protected': False, 'default_profile': True, 'is_translator': False,
    'text': '047adb82b3000000',
    'source': '<a href="http://www.google.com/" rel="nofollow">Google</a>',
    'geo': {
        'type': 'Point', 'coordinates': [29.10438635, -64.47487041]
    },
    'user': {
        'follow_request_sent': None, 'has_extended_profile': False, 'profile_use_background_image': True, 'default_profile_image': True, 'id': 61043461,
        'profile_background_image_url_https': 'https://abs.twimg.com/images/themes/theme1/bg.png', 'verified': False, 'profile_text_color': '333333',
        'profile_image_url_https': 'https://abs.twimg.com/sticky/default_profile_images/default_profile_3_normal.png', 'profile_sidebar_fill_color': 'DDEEF6',
        'entities': {'description': {'urls': []}}, 'followers_count': 114, 'profile_sidebar_border_color': 'C0DEED', 'id_str': '61043461', 'profile_background_color': 'C0DEED', 'listed_count': 22,
        'is_translation_enabled': False, 'utc_offset': -14400, 'statuses_count': 654785, 'description': '', 'friends_count': 0, 'location': '', 'profile_link_color': '0084B4',
        'profile_image_url': 'http://abs.twimg.com/sticky/default_profile_images/default_profile_3_normal.png', 'following': None, 'geo_enabled': True,
        'profile_background_image_url': 'http://abs.twimg.com/images/themes/theme1/bg.png', 'screen_name': 'googuns_prod', 'lang': 'en', 'profile_background_tile': False, 'favourites_count': 0,
        'name': 'GooGuns', 'notifications': None, 'url': None, 'created_at': 'Tue Jul 28 22:49:22 +0000 2009', 'contributors_enabled': False, 'time_zone': 'Eastern Time (US & Canada)',
        'protected': False, 'default_profile': True, 'is_translator': False
    }
}


class TestCase(unittest.TestCase):

    api = tweepy.API()
    status = tweepy.Status.parse(api, TWEET)

    def test_basics(self):
        assert hasattr(twittergeo, 'feature')
        assert hasattr(twittergeo, 'collection')

    def test_feature(self):
        feature = twittergeo.feature(self.status)

        assert feature['type'] == 'Feature'
        assert feature['geometry']['type'] == 'Point'
        assert feature['geometry']['coordinates'] == [-64.47487041, 29.10438635]

        assert feature['properties']['friends_count'] == 0
        assert feature['properties']['user']['screen_name'] == 'googuns_prod'

    def test_feature_lite(self):
        feature = twittergeo.feature(self.status, lite=True)
        assert feature['properties']['screen_name'] == 'googuns_prod'

    def test_collection(self):
        collection = twittergeo.collection()
        collection['features'] = [twittergeo.feature(self.status)]
        request = requests.post(validate_endpoint, data=json.dumps(collection))
        assert request.ok is True



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of twittergeo.
# https://github.com/fitnr/twittergeo

# Licensed under the GNU General Public License v3 (GPLv3) license:
# http://opensource.org/licenses/GPL-3.0
# Copyright (c) 2015, Neil Freeman <contact@fakeisthenewreal.org>


__all__ = [
    'test_cli',
    'test_twittergeo'
]

from . import test_cli
from . import test_twittergeo



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of twittergeo.
# https://github.com/fitnr/twittergeo

# Licensed under the GNU General Public License v3 (GPLv3) license:
# http://opensource.org/licenses/GPL-3.0
# Copyright (c) 2015, Neil Freeman <contact@fakeisthenewreal.org>

from .twittergeo import twittergeo
from .twittergeo import collection
from .twittergeo import feature

__version__ = '0.2.1'
__author__ = 'Neil Freeman'
__license__ = 'GPL-3.0'
__all__ = ['twittergeo']



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of twittergeo.
# https://github.com/fitnr/twittergeo

# Licensed under the GNU General Public License v3 (GPLv3) license:
# http://opensource.org/licenses/GPL-3.0
# Copyright (c) 2015, Neil Freeman <contact@fakeisthenewreal.org>

import argparse
import json
from twitter_bot_utils import API

from .twittergeo import twittergeo


def main():
    parser = argparse.ArgumentParser('twittergeo', description='Pull Twitter searches into GeoJSON')

    parser.add_argument('-c', '--config', dest='config_file', metavar='path', default=None, type=str, help='jsom or yaml config file')
    parser.add_argument('--app', default='twittergeo', type=str, help='Twitter app to read in config (default: %(default)s)')
    parser.add_argument('--consumer-key', type=str, help=argparse.SUPPRESS)
    parser.add_argument('--consumer-secret', type=str, help=argparse.SUPPRESS)

    group = parser.add_mutually_exclusive_group()
    group.add_argument('-u', '--user', type=str, dest='screen_name', metavar='screen_name', help='User timeline to search')
    group.add_argument('-f', '--search', type=str, dest='q', metavar='search', help='Search string')

    parser.add_argument('--lite', action='store_true', help='Output minimal information about tweets')
    parser.add_argument('--count', type=int, default=500, help='Maximum number of tweets to return (default: %(default)s)')

    parser.add_argument('--geocode', type=str, metavar='LAT,LON,RADIUS', help='optional geocode parameter when searching')

    parser.add_argument('--since', dest='since_id', metavar='ID', type=int, help='Fetch tweets since this ID')
    parser.add_argument('--max', dest='max_id', metavar='ID', type=int, help='Fetch tweets before this ID')

    parser.add_argument('-o', '--output', type=str, help='output file (default: stdout)', default='/dev/stdout')

    arguments = parser.parse_args()
    twitter = API(arguments, logger_name='twittergeo')

    if getattr(arguments, 'screen_name'):
        method = twitter.user_timeline

    if getattr(arguments, 'q'):
        method = twitter.search

    keys = ('q', 'screen_name', 'geocode', 'since_id', 'max_id')
    kwargs = {k: v for k, v in vars(arguments).items() if k in keys and v is not None}
    kwargs['result_type'] = 'recent'

    geojson = twittergeo(method, arguments.count, arguments.lite, **kwargs)

    with open(arguments.output, 'w') as f:
        json.dump(geojson, f)

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of twittergeo.
# https://github.com/fitnr/twittergeo

# Licensed under the GNU General Public License v3 (GPLv3) license:
# http://opensource.org/licenses/GPL-3.0
# Copyright (c) 2015, Neil Freeman <contact@fakeisthenewreal.org>

from setuptools import setup

try:
    readme = open('README.rst').read()
except IOError:
    try:
        readme = open('README.md').read()
    except IOError:
        readme = ''

with open('twittergeo/__init__.py') as i:
    version = next(r for r in i.readlines() if '__version__' in r).split('=')[1].strip('"\' \n')

setup(
    name='twittergeo',
    version=version,
    description='Export Twitter searches to GeoJSON',
    long_description=readme,
    keywords='twitter geo cli',
    author='Neil Freeman',
    author_email='contact@fakeisthenewreal.org',
    url='https://github.com/fitnr/twittergeo',
    license='GNU General Public License v3 (GPLv3)',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: Unix',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Operating System :: OS Independent',
    ],

    packages=['twittergeo'],

    include_package_data=False,
    install_requires=[
        'twitter_bot_utils>=0.10.2',
    ],

    test_suite="tests",

    tests_require=[
        'mock',
    ],

    entry_points={
        'console_scripts': [
            'twittergeo=twittergeo.cli:main',
        ],
    },
)
